EXPORTS
	GetWordSettings__3HCRiPCQ23HCR10SSettingIdPlPQ23HCR12TSettingTypePi @ 1  NONAME ; HCR::GetWordSettings(int, HCR::SSettingId const *, long *, HCR::TSettingType *, int *)
	GetData__3HCRRCQ23HCR10TSettingIdR5TDes8 @ 2  NONAME R3UNUSED ; HCR::GetData(HCR::TSettingId const &, TDes8 &)
	GetData___3HCRRCQ23HCR10TSettingIdUsPUcRUs @ 3  NONAME ; HCR::GetData_(HCR::TSettingId const &, unsigned short, unsigned char *, unsigned short &)
	GetInt__3HCRRCQ23HCR10TSettingIdRSc @ 4  NONAME R3UNUSED ; HCR::GetInt(HCR::TSettingId const &, signed char &)
	GetInt__3HCRRCQ23HCR10TSettingIdRl @ 5  NONAME R3UNUSED ; HCR::GetInt(HCR::TSettingId const &, long &)
	GetInt__3HCRRCQ23HCR10TSettingIdRs @ 6  NONAME R3UNUSED ; HCR::GetInt(HCR::TSettingId const &, short &)
	GetInt__3HCRRCQ23HCR10TSettingIdRx @ 7  NONAME R3UNUSED ; HCR::GetInt(HCR::TSettingId const &, long long &)
	GetLinAddr__3HCRRCQ23HCR10TSettingIdRUl @ 8  NONAME R3UNUSED ; HCR::GetLinAddr(HCR::TSettingId const &, unsigned long &)
	GetString__3HCRRCQ23HCR10TSettingIdR5TDes8 @ 9  NONAME R3UNUSED ; HCR::GetString(HCR::TSettingId const &, TDes8 &)
	GetString___3HCRRCQ23HCR10TSettingIdUsPUcRUs @ 10  NONAME ; HCR::GetString_(HCR::TSettingId const &, unsigned short, unsigned char *, unsigned short &)
	GetTypeAndSize__3HCRRCQ23HCR10TSettingIdRQ23HCR12TSettingTypeRUs @ 11  NONAME R3UNUSED ; HCR::GetTypeAndSize(HCR::TSettingId const &, HCR::TSettingType &, unsigned short &)
	GetUInt__3HCRRCQ23HCR10TSettingIdRUc @ 12  NONAME R3UNUSED ; HCR::GetUInt(HCR::TSettingId const &, unsigned char &)
	GetUInt__3HCRRCQ23HCR10TSettingIdRUl @ 13  NONAME R3UNUSED ; HCR::GetUInt(HCR::TSettingId const &, unsigned long &)
	GetUInt__3HCRRCQ23HCR10TSettingIdRUs @ 14  NONAME R3UNUSED ; HCR::GetUInt(HCR::TSettingId const &, unsigned short &)
	GetUInt__3HCRRCQ23HCR10TSettingIdRUx @ 15  NONAME R3UNUSED ; HCR::GetUInt(HCR::TSettingId const &, unsigned long long &)
	GetBool__3HCRRCQ23HCR10TSettingIdRi @ 16  NONAME R3UNUSED ; HCR::GetBool(HCR::TSettingId const &, int &)
	GetArray__3HCRRCQ23HCR10TSettingIdUsPlRUs @ 17  NONAME ; HCR::GetArray(HCR::TSettingId const &, unsigned short, long *, unsigned short &)
	GetArray__3HCRRCQ23HCR10TSettingIdUsPUlRUs @ 18  NONAME ; HCR::GetArray(HCR::TSettingId const &, unsigned short, unsigned long *, unsigned short &)
	FindSettings__3HCRUliRUlPUlPQ23HCR12TSettingTypePUs @ 19  NONAME ; HCR::FindSettings(unsigned long, int, unsigned long &, unsigned long *, HCR::TSettingType *, unsigned short *)
	FindSettings__3HCRUliUlUlUlRUlPUlPQ23HCR12TSettingTypePUs @ 20  NONAME ; HCR::FindSettings(unsigned long, int, unsigned long, unsigned long, unsigned long, unsigned long &, unsigned long *, HCR::TSettingType *, unsigned short *)
	FindNumSettingsInCategory__3HCRUl @ 21  NONAME R3UNUSED ; HCR::FindNumSettingsInCategory(unsigned long)
